==> openscada-0.9.0.tar.xz: openscada-0.9.0/src/moduls/ui/WebVision/VCAhtml.cpp <==
const char *WebVisionVCA_html=
   "<?xml version='1.0' ?>\n"
   "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN'\n"
   "'DTD/xhtml1-transitional.dtd'>\n"
   "<html xmlns='http://www.w3.org/1999/xhtml'>\n"
   "<head>\n"
   "  <meta http-equiv='Content-Type' content='text/html; charset=##CHARSET##'/>\n"
   "  <meta http-equiv='Cache-Control' content='no-store, no-cache, must-revalidate'/>\n"
   "  <meta http-equiv='Cache-Control' content='post-check=0, pre-check=0'/>\n"
   "  <link rel='shortcut icon' href='/WebVision/ico' type='image' />\n"
   "  <title>##TITLE##</title>\n"
   "  <style type='text/css'>\n"
   "    hr { width: 95%; }\n"
   "    body { background-color: #B0B0B0; margin: 0px; }\n"
   "    button { border-width: 2px; }\n"
   "    h1.head { text-align: center; color: #ffff00; }\n"
   "    h2.title { text-align: center; font-style: italic; margin: 0px; padding: 0px; border-width: 0; }\n"
   "    table.work { background-color: #9999ff; border: 3px ridge #a9a9a9; padding: 2px; }\n"
   "    table.work td { background-color: #cccccc; text-align: left; }\n"
   "    table.work td.content { padding: 5px; padding-bottom: 20px; }\n"
   "    /*table.work td.content td { text-align: center; }*/\n"
   "    table.work td.content img { vertical-align: middle; padding-right: 5px; }\n"
   "    table.work ul { margin: 0px; padding: 0px; padding-left: 20px; }\n"
   "    .vertalign { display: table-cell; text-align: center; vertical-align: middle; }\n"
   "    .vertalign * { vertical-align: middle; }\n"
   "    table.prot { border: 1px solid black; border-collapse: collapse; empty-cells: show; }\n"
   "    table.prot th { border: 1px solid black; background-color: #E6E6E6; text-align: center; white-space: nowrap; }\n"
   "    table.prot td { border: 1px solid black; white-space: nowrap; }\n"
   "    table.prot td.hd { background-color: #E6E6E6; font-weight: bold; text-align: center; }\n"
   "    #gen-pnl-dlg { position: absolute; font-size: 12px; z-index: 9999; background-color: #8FA9FF; border: 1px solid darkblue; box-shadow: 10px 10px 5px rgba(68,68,68,0.6); }\n"
   "    #gen-pnl-dlg tr.hd { font-size: 12pt; cursor: move; background: linear-gradient(#8FA9FF, #6F89DF, #8FA9FF); }\n"
   "    #gen-pnl-status { position: absolute; left: 0px; overflow: hidden; border-top: 1px solid darkblue; }\n"
   "    #gen-pnl-status td { padding-left: 5px; padding-right: 5px; text-align: left; }\n"
   "    #st_user { border-left: 1px solid black; padding-left: 2px; white-space: nowrap; }\n"
   "    #popupmenu { position: absolute; border: 0; width: 150px; height: 150px; overflow : auto; z-index: 1000; }\n"
   "    #popupmenu select { background-color: #E6E6E6; border: 1px solid black; padding: 1px; width: auto; }\n"
   "    #combomenu { position: absolute; visibility: visible; border: 0; }\n"
   "    #combomenu select { border-width: 2px; padding: 1px; }\n"
   "    #clndrdlg { position: absolute; visibility: visible; border: 0; background-color: white; border: 1px solid gray; padding: 1px; height: auto; width: auto; text-align: center; }\n"
   "    #clndrdlg input, select { width: 33%; font: inherit; }\n"
   "    #clndrdlg table { width: 100%; }\n"
   "    #clndrdlg table td.active { cursor: pointer; }\n"
   "    #clndrdlg table .end { color: red; }\n"
   "    #clndrdlg table td.sel { font-weight: bold; }\n"
   "    #menuwin { position: absolute; visibility: visible; border: 0; background-color: white; border: 1px solid gray; padding: 1px; height: auto; width: auto; }\n"
   "    input[type=\"checkbox\"] { margin: 0 4px 0 0; float: left; }\n"
   "    div.FormEl { position: absolute; }\n"
   "    .FormEl input.LineEd { position: absolute; left: 0px; border: 1px solid gray; padding: 1px; }\n"
   "    .FormEl img.ok { visibility: hidden; position: absolute; width: 16px; height: 16px; cursor: pointer; }\n"
   "    .FormEl .cntr { position: absolute; width: 16px; cursor: pointer; }\n"
   "    .FormEl select { position: absolute; left: 0px; border: 1px solid gray; padding: 0; line-height: 1; }\n"
   "    .FormEl textarea { border: 1px solid gray; padding: 1px; }\n"
   "    .FormEl input[type=range], .FormEl input[type=file] { position: absolute; top: 0; bottom: 0; left: 0; right: 0; margin: auto; }\n"
   "    .FormEl input[type=range][orient=vertical] { writing-mode: bt-lr; -webkit-appearance: slider-vertical; }\n"
   "    .FormEl img.inactive { filter: grayscale(100%) opacity(30%); }\n"
   "    div.FormEl.Table, div.FormEl.ItemsTree { background-color: white; border: 1px solid gray; padding: 1px; overflow: auto; text-align: left; }\n"
   "    div.FormEl.Table table { border-collapse: collapse; }\n"
   "    div.FormEl.Table table th { text-align: center; background-color: #e6e6e6; border: 1px solid black; white-space: pre-line; word-break: break-all; }\n"
   "    div.FormEl.Table table td { border: 1px solid black; white-space: pre-line; word-break: break-all; vertical-align: middle; }\n"
   "    div.FormEl.Table table td * { vertical-align: middle; }\n"
   "    div.FormEl.Table table td input { font: inherit; }\n"
   "    div.FormEl.Table.active th, div.FormEl.Table.active td { cursor: pointer; }\n"
   "    /*div.FormEl.Table table td img { float: left; margin-right: 3px; }*/\n"
   "    div.ItemsTree ul { background-color: white; list-style-image: none; list-style-position: outside; list-style-type: none; background-repeat: repeat-y; background-attachment: scroll; background-position: left top; margin: 0; white-space: nowrap; }\n"
   "    div.ItemsTree > ul { padding: 0; }\n"
   "    div.ItemsTree > ul ul { padding: 0 0 0 17px; }\n"
   "    div.ItemsTree img { vertical-align: middle; height: 16px; }\n"
   "    div.ItemsTree span { line-height: 1; }\n"
   "    div.ItemsTree li.selectable { font-style: normal; }\n"
   "    div.ItemsTree li.select { background-color: #BDEBED; }\n"
   "    div.ItemsTree.active li.expandable img, div.ItemsTree.active li.selectable span { cursor: pointer; }\n"
   "    /*div.ItemsTree li.select span { cursor: pointer; }*/\n"
   "    div.Media { position: absolute; border-style: solid; overflow: hidden; }\n"
   "    div.Media img { position: absolute; top: 0; bottom: 0; left: 0; right: 0; margin: auto; }\n"
   "}\n"
   "  </style>\n"
   "</head>\n"
   "<body>\n"
   "<script src='/WebVision/script.js' type='text/javascript'></script>\n"
   "</body>\n"
   "</html>\n";

==> openscada-0.9.1.tar.xz: openscada-0.9.1/src/moduls/ui/WebVision/VCAhtml.cpp <==
const char *WebVisionVCA_html=
   "<?xml version='1.0' ?>\n"
   "<!DOCTYPE html PUBLIC '-//W3C//DTD XHTML 1.0 Transitional//EN' 'http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd'>\n"
   "<html xmlns='http://www.w3.org/1999/xhtml'>\n"
   "<head>\n"
   "  <meta http-equiv='Content-Type' content='text/html; charset=##CHARSET##'/>\n"
   "  <meta http-equiv='Cache-Control' content='no-store, no-cache, must-revalidate'/>\n"
   "  <meta http-equiv='Cache-Control' content='post-check=0, pre-check=0'/>\n"
   "  <link rel='shortcut icon' href='/WebVision/ico' type='image' />\n"
   "  <title>##TITLE##</title>\n"
   "  <style type='text/css'>\n"
   "    hr { width: 95%; }\n"
   "    body { background-color: #B0B0B0; margin: 0px; }\n"
   "    button { border-width: 2px; overflow: hidden; }\n"
   "    h1.head { text-align: center; color: #ffff00; }\n"
   "    h2.title { text-align: center; font-style: italic; margin: 0px; padding: 0px; border-width: 0; }\n"
   "    table.work { background-color: #9999ff; border: 3px ridge #a9a9a9; padding: 2px; }\n"
   "    table.work td { background-color: #cccccc; text-align: left; }\n"
   "    table.work td.content { padding: 5px; padding-bottom: 20px; }\n"
   "    /*table.work td.content td { text-align: center; }*/\n"
   "    table.work td.content img { vertical-align: middle; padding-right: 5px; }\n"
   "    table.work ul { margin: 0px; padding: 0px; padding-left: 20px; }\n"
   "    .vertalign { display: table-cell; text-align: center; vertical-align: middle; }\n"
   "    .vertalign * { vertical-align: middle; }\n"
   "    table.prot { border: 1px solid black; border-collapse: collapse; empty-cells: show; }\n"
   "    table.prot th { border: 1px solid black; background-color: #E6E6E6; text-align: center; white-space: nowrap; }\n"
   "    table.prot td { border: 1px solid black; white-space: nowrap; }\n"
   "    table.prot td.hd { background-color: #E6E6E6; font-weight: bold; text-align: center; }\n"
   "    #gen-pnl-dlg { position: absolute; font-size: 12px; z-index: 9999; background-color: #8FA9FF; border: 1px solid darkblue; box-shadow: 10px 10px 5px rgba(68,68,68,0.6); }\n"
   "    #gen-pnl-dlg tr.hd { font-size: 12pt; cursor: move; background: linear-gradient(#8FA9FF, #6F89DF, #8FA9FF); }\n"
   "    #gen-pnl-status { position: absolute; left: 0px; overflow: hidden; border-top: 1px solid darkblue; }\n"
   "    #gen-pnl-status table { border-spacing: 0px; }\n"
   "    #gen-pnl-status td { padding-left: 5px; padding-right: 5px; text-align: left; }\n"
   "    #st_user, #st_style, #st_alarm { border-left: 1px solid black; padding-left: 2px; white-space: nowrap; }\n"
   "    #st_style select { width: auto; padding: 0; border: 1px solid gray; }\n"
   "    #popupmenu { position: absolute; border: 1px solid gray; width: 150px; height: 150px; overflow: auto; z-index: 1000; background-color: #E6E6E6; }\n"
   "    #popupmenu select { border: 0; background-color: #E6E6E6; padding: 1px; width: auto; overflow-y: hidden; overflow-x: hidden; }\n"
   "    #combomenu { position: absolute; visibility: visible; border: 0; }\n"
   "    #combomenu select { border-width: 2px; padding: 1px; }\n"
   "    #clndrdlg { position: absolute; visibility: visible; background-color: white; border: 1px solid gray; padding: 1px; height: auto; width: auto; text-align: center; }\n"
   "    #clndrdlg input, select { width: 33%; font: inherit; }\n"
   "    #clndrdlg table { width: 100%; }\n"
   "    #clndrdlg table td.active { cursor: pointer; }\n"
   "    #clndrdlg table .end { color: red; }\n"
   "    #clndrdlg table td.sel { font-weight: bold; }\n"
   "    #menuwin { position: absolute; visibility: visible; border: 0; background-color: white; border: 1px solid gray; padding: 1px; height: auto; width: auto; }\n"
   "    input[type=\"checkbox\"] { margin: 0 4px 0 0; float: left; }\n"
   "    div.FormEl { position: absolute; }\n"
   "    .FormEl input.LineEd { position: absolute; left: 0px; }\n"
   "    .FormEl img.ok { visibility: hidden; position: absolute; cursor: pointer; }\n"
   "    .FormEl .cntr { position: absolute; width: 16px; cursor: pointer; }\n"
   "    .FormEl select { position: absolute; left: 0px; border: 1px solid gray; padding: 0; line-height: 1; }\n"
   "    .FormEl input[type=range], .FormEl input[type=file] { position: absolute; top: 0; bottom: 0; left: 0; right: 0; margin: auto; }\n"
   "    .FormEl input[type=range][orient=vertical] { writing-mode: bt-lr; -webkit-appearance: slider-vertical; }\n"
   "    .FormEl img.inactive { filter: grayscale(100%) opacity(30%); }\n"
   "    div.FormEl.Table, div.FormEl.ItemsTree { overflow: auto; text-align: left; border: 1px solid gray; background-color: white; }\n"
   "    div.FormEl.Table table { border-collapse: collapse; }\n"
   "    div.FormEl.Table table th { text-align: center; background-color: #e6e6e6; border: 1px solid black; white-space: pre-line; }\n"
   "    div.FormEl.Table table td { border: 1px solid black; white-space: pre-line; vertical-align: middle; }\n"
   "    div.FormEl.Table table td * { vertical-align: middle; }\n"
   "    div.FormEl.Table table td input { font: inherit; }\n"
   "    div.FormEl.Table.active th, div.FormEl.Table.active td { cursor: pointer; }\n"
   "    /*div.FormEl.Table table td img { float: left; margin-right: 3px; }*/\n"
   "    div.ItemsTree ul { list-style-image: none; list-style-position: outside; list-style-type: none; background-repeat: repeat-y; background-attachment: scroll; background-position: left top; margin: 0; white-space: nowrap; }\n"
   "    div.ItemsTree > ul { padding: 0; }\n"
   "    div.ItemsTree > ul ul { padding: 0 0 0 17px; }\n"
   "    div.ItemsTree img { vertical-align: middle; }\n"
   "    div.ItemsTree span { line-height: 1; }\n"
   "    div.ItemsTree li.selectable { font-style: normal; }\n"
   "    div.ItemsTree li.select { background-color: #BDEBED; }\n"
   "    div.ItemsTree.active li.expandable img, div.ItemsTree.active li.selectable span { cursor: pointer; }\n"
   "    /*div.ItemsTree li.select span { cursor: pointer; }*/\n"
   "    div.Media { position: absolute; border-style: solid; overflow: hidden; }\n"
   "    div.Media img { position: absolute; top: 0; bottom: 0; left: 0; right: 0; margin: auto; }\n"
   "}\n"
   "  </style>\n"
   "</head>\n"
   "<body>\n"
   "<script src='/WebVision/script.js' type='text/javascript'></script>\n"
   "</body>\n"
   "</html>\n";
